@@ -1,10 +1,8 @@
 package App::Sky::Module;
-
+$App::Sky::Module::VERSION = '0.4.0';
 use strict;
 use warnings;
 
-our $VERSION = '0.2.1';
-
 
 use Carp ();
 
@@ -19,62 +17,58 @@ use List::MoreUtils qw( uniq );
 use App::Sky::Results;
 use App::Sky::Exception;
 
-has base_upload_cmd => (isa => 'ArrayRef[Str]', is => 'ro',);
-has dest_upload_prefix => (isa => 'Str', is => 'ro',);
-has dest_upload_url_prefix => (isa => 'Str', is => 'ro',);
+has base_upload_cmd        => ( isa => 'ArrayRef[Str]', is => 'ro', );
+has dest_upload_prefix     => ( isa => 'Str',           is => 'ro', );
+has dest_upload_url_prefix => ( isa => 'Str',           is => 'ro', );
 
 
 sub get_upload_results
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
-    my $is_dir = ($args->{is_dir} // 0);
+    my $is_dir = ( $args->{is_dir} // 0 );
 
     my $filenames = $args->{filenames}
-        or Carp::confess ("Missing argument 'filenames'");
+        or Carp::confess("Missing argument 'filenames'");
 
-    if (@$filenames != 1)
+    if ( @$filenames != 1 )
     {
-        Carp::confess ("More than one file passed to 'filenames'");
+        Carp::confess("More than one file passed to 'filenames'");
     }
 
     my $target_dir = $args->{target_dir}
-        or Carp::confess ("Missing argument 'target_dir'");
+        or Carp::confess("Missing argument 'target_dir'");
 
     my $invalid_chars_re = qr/[:]/;
 
-    my @invalid_chars = (map { split( //, $_) } map { /($invalid_chars_re)/g } @$filenames);
+    my @invalid_chars =
+        ( map { split( //, $_ ) } map { /($invalid_chars_re)/g } @$filenames );
 
     if (@invalid_chars)
     {
         App::Sky::Exception::Upload::Filename::InvalidChars->throw(
-            invalid_chars =>
-            [sort { $a cmp $b } uniq(@invalid_chars)],
-        );
+            invalid_chars => [ sort { $a cmp $b } uniq(@invalid_chars) ], );
     }
 
     return App::Sky::Results->new(
         {
-            upload_cmd =>
-            [
-                @{$self->base_upload_cmd()},
+            upload_cmd => [
+                @{ $self->base_upload_cmd() },
                 @$filenames,
-                ($self->dest_upload_prefix() . $target_dir),
+                ( $self->dest_upload_prefix() . $target_dir ),
             ],
-            urls =>
-            [
+            urls => [
                 URI->new(
-                    $self->dest_upload_url_prefix()
-                    . $target_dir
-                    . basename($filenames->[0])
-                    . ($is_dir ? '/' : '')
+                          $self->dest_upload_url_prefix()
+                        . $target_dir
+                        . basename( $filenames->[0] )
+                        . ( $is_dir ? '/' : '' )
                 ),
             ],
         }
     );
 }
 
-
 1;
 
 __END__
@@ -85,11 +79,19 @@ __END__
 
 =head1 NAME
 
+App::Sky::Module
+
+=head1 VERSION
+
+version 0.4.0
+
+=head1 NAME
+
 App::Sky::Module - class that does the heavy lifting.
 
 =head1 VERSION
 
-version 0.2.1
+version 0.4.0
 
 =head1 METHODS
 
@@ -127,38 +129,10 @@ The upload command to execute (as an array reference of strings).
 
 =back
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2013 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=App-Sky or by email to
-bug-app-sky@rt.cpan.org.
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc App::Sky
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -172,7 +146,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/App-Sky>
+L<https://metacpan.org/release/App-Sky>
 
 =item *
 
@@ -188,7 +162,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=App-Sky>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-Sky>
 
 =item *
 
@@ -208,25 +182,17 @@ L<http://cpanratings.perl.org/d/App-Sky>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/App-Sky>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/App-Sky>
+L<http://cpants.cpanauthors.org/dist/App-Sky>
 
 =item *
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/A/App-Sky>
 
@@ -251,7 +217,7 @@ L<http://deps.cpantesters.org/?module=App::Sky>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-app-sky at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=App-Sky>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=App-Sky>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
@@ -264,4 +230,25 @@ L<https://github.com/shlomif/Sky-uploader>
 
   git clone git://github.com/shlomif/Sky-uploader.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/Sky-uploader/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
